==> haskell-criterion-1.6.2.0-28-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-criterion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 criterion
version:              1.6.2.0
visibility:           public
id:                   criterion-1.6.2.0-IievOFtm9lDKNqeTy1A9BZ
key:                  criterion-1.6.2.0-IievOFtm9lDKNqeTy1A9BZ
license:              BSD-3-Clause
copyright:            2009-2016 Bryan O'\''Sullivan and others
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://www.serpentine.com/criterion
synopsis:             Robust, reliable performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.

    The fastest way to get started is to read the
    <http://www.serpentine.com/criterion/tutorial.html online tutorial>,
    followed by the documentation and examples in the "Criterion.Main"
    module.

    For examples of the kinds of reports that criterion generates, see
    <http://www.serpentine.com/criterion the home page>.

category:             Development, Performance, Testing, Benchmarking
abi:                  6f5cbcb4648a278e4538e4ce07de04a2
exposed:              True
exposed-modules:
    Criterion Criterion.Analysis Criterion.IO Criterion.IO.Printf
    Criterion.Internal Criterion.Main Criterion.Main.Options
    Criterion.Monad Criterion.Report Criterion.Types

hidden-modules:       Criterion.Monad.Internal Paths_criterion
import-dirs:          /usr/lib/ghc-9.4.8/site-local/criterion-1.6.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/criterion-1.6.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/criterion-1.6.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-criterion
hs-libraries:         HScriterion-1.6.2.0-IievOFtm9lDKNqeTy1A9BZ
depends:
    Glob-0.10.2-4hGAIIuIwc1EHm05XfQPMH
    aeson-2.1.2.1-JD8QPsoBF4NC1qVY6ch6us base-4.17.2.1
    base-compat-batteries-0.13.0-Et724wDiiqBBlWE58fGIXy binary-0.8.9.1
    binary-orphans-1.0.5-1KzR7x2hzsFEzWqnKHOT5t bytestring-0.11.5.3
    cassava-0.5.4.0-2EwfR9DgOd81pSJygy17qc
    code-page-0.2.1-LeQPy5FeQvS92HSQRBnpzj containers-0.6.7
    criterion-measurement-0.2.3.0-FquMxXIrIj2GGEIDBT0iXV
    deepseq-1.4.8.0 directory-1.3.7.1 exceptions-0.10.5
    filepath-1.4.2.2 js-chart-2.9.4.1-IBsFHDloWlsCcv9nYHmzO5
    microstache-1.0.2.3-JsseBUziCSVGtCdZiRhwmZ mtl-2.2.2
    mwc-random-0.15.2.0-ELj4qUiZnLmAQm95Zp4Gs6
    optparse-applicative-0.18.1.0-7qc0weJVpOv49HyNgUQM9q
    parsec-3.1.16.1 prettyprinter-1.7.1-5cxpZ3jZU7h3nFjq43pkKP
    prettyprinter-ansi-terminal-1.1.3-DOKqyPGKM8ODcj1VptIqod
    statistics-0.16.3.0-LAIoIjdPTPH4jbxPnJTuYe text-2.0.2 time-1.12.2
    transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    vector-0.13.2.0-L6HpF7nmtGm1K7R40olL6U
    vector-algorithms-0.9.1.0-LoT4ntDbcFM3fTUkbg6aQi

haddock-interfaces:   /usr/share/doc/haskell-criterion/html/criterion.haddock
haddock-html:         /usr/share/doc/haskell-criterion/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-criterion-1.6.2.0-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-criterion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 criterion
version:              1.6.2.0
visibility:           public
id:                   criterion-1.6.2.0-8MdFjDfFbZYIZGg2Jp55Sv
key:                  criterion-1.6.2.0-8MdFjDfFbZYIZGg2Jp55Sv
license:              BSD-3-Clause
copyright:            2009-2016 Bryan O'\''Sullivan and others
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://www.serpentine.com/criterion
synopsis:             Robust, reliable performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.

    The fastest way to get started is to read the
    <http://www.serpentine.com/criterion/tutorial.html online tutorial>,
    followed by the documentation and examples in the "Criterion.Main"
    module.

    For examples of the kinds of reports that criterion generates, see
    <http://www.serpentine.com/criterion the home page>.

category:             Development, Performance, Testing, Benchmarking
abi:                  38e130bb14c591ecae0bed0abab985be
exposed:              True
exposed-modules:
    Criterion Criterion.Analysis Criterion.IO Criterion.IO.Printf
    Criterion.Internal Criterion.Main Criterion.Main.Options
    Criterion.Monad Criterion.Report Criterion.Types

hidden-modules:       Criterion.Monad.Internal Paths_criterion
import-dirs:          /usr/lib/ghc-9.4.8/site-local/criterion-1.6.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/criterion-1.6.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/criterion-1.6.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-criterion
hs-libraries:         HScriterion-1.6.2.0-8MdFjDfFbZYIZGg2Jp55Sv
depends:
    Glob-0.10.2-E5IDx0f7QZU99aBskOMObW
    aeson-2.1.2.1-H1ahbkp4Y7o4mfa4dlXJ2M base-4.17.2.1
    base-compat-batteries-0.13.0-BMAS8Gep38251oHfjMoLhV binary-0.8.9.1
    binary-orphans-1.0.5-1rsiMYvrmH28EsZsA67Giu bytestring-0.11.5.3
    cassava-0.5.4.0-lfuqYmKT2FMdjygGYhLT
    code-page-0.2.1-LeQPy5FeQvS92HSQRBnpzj containers-0.6.7
    criterion-measurement-0.2.3.0-Le5HmnhLUQAAcFJDcVcyMJ
    deepseq-1.4.8.0 directory-1.3.7.1 exceptions-0.10.5
    filepath-1.4.2.2 js-chart-2.9.4.1-IBsFHDloWlsCcv9nYHmzO5
    microstache-1.0.2.3-GKfoyixefLiExKr7zcdaLe mtl-2.2.2
    mwc-random-0.15.2.0-LJaQm1REvalG7fjWGvG3mt
    optparse-applicative-0.18.1.0-7a3VGVGHpDh9ZqkU0lCBOm
    parsec-3.1.16.1 prettyprinter-1.7.1-27Ta3g9m3VQHgx6FjDiyXu
    prettyprinter-ansi-terminal-1.1.3-DxfNV5472scK2uuBICYXIT
    statistics-0.16.3.0-C2woAUsEtxcI2yYQiV1ybP text-2.0.2 time-1.12.2
    transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    vector-0.13.2.0-LTUcBi4LXgv7CSERMHHzQp
    vector-algorithms-0.9.1.0-B0WxivUHCxHIEgxlZRlMPG

haddock-interfaces:   /usr/share/doc/haskell-criterion/html/criterion.haddock
haddock-html:         /usr/share/doc/haskell-criterion/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
